@@ -9,13 +9,10 @@ import sys, os, os.path
 import errno
 import gettext 
 
-if (sys.modules.has_key('glchess') and
-    hasattr(sys.modules["glchess"],'installed_mode') and
-    sys.modules["glchess"].installed_mode):
-    # If the installed_mode attribute is not set, then we are
-    # importing from something other than the glchess script; we
-    # assume anyone importing in this way is doing testing etc.
-    APP_DATA_DIR     = os.path.join('/home/thomas/svn/test5', 'share') 
+root_dir = os.path.dirname(os.path.dirname(__file__))
+if not os.path.exists(os.path.join(root_dir, "Makefile.am")):
+    # Running in installed mode
+    APP_DATA_DIR     = os.path.join('/usr/local', 'share') 
     ICON_DIR         = os.path.join(APP_DATA_DIR, 'pixmaps')
     TEXTURE_DIR      = os.path.join(ICON_DIR, 'glchess')
     GLADE_DIR        = os.path.join(APP_DATA_DIR, 'glchess')
@@ -28,11 +25,13 @@ if (sys.modules.has_key('glchess') and
     UNFINISHED_FILE  = os.path.join(HISTORY_DIR, 'unfinished')
     LOCAL_AI_CONFIG  = os.path.join(DATA_DIR, 'ai.xml')
 else:
-    APP_DATA_DIR     = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'data')
-    ICON_DIR         = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'textures')
-    TEXTURE_DIR      = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'textures')
-    GLADE_DIR        = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'glade')
-    BASE_DIR         = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'data')
+    # Running in uninstalled mode
+    sys.path.insert(0, os.path.abspath(root_dir))
+    APP_DATA_DIR     = os.path.join(root_dir, '../data')
+    ICON_DIR         = os.path.join(root_dir, '../textures')
+    TEXTURE_DIR      = os.path.join(root_dir, '../textures')
+    GLADE_DIR        = os.path.join(root_dir, '../glade')
+    BASE_DIR         = os.path.join(root_dir, '../data')
     LOCALEDIR        = os.path.join(APP_DATA_DIR, 'locale')
     DATA_DIR         = os.path.expanduser('~/.gnome2/glchess/')
     LOG_DIR          = os.path.join(DATA_DIR, 'logs')
@@ -50,7 +49,7 @@ import gtk.glade
 gtk.glade.bindtextdomain(DOMAIN, LOCALEDIR)
 gtk.glade.textdomain(DOMAIN)
 
-VERSION   = "2.21.91"
+VERSION   = "2.22.2.1"
 APPNAME   = _("glChess")
 ICON_NAME = 'gnome-glchess'
 
