@@ -420,6 +420,11 @@ class ChessGame:
         if not self.__blackPlayer.isAlive:
             self.killPlayer(self.__blackPlayer)
             return
+        
+        # Stop if game ended on loaded moves
+        if self.result != RESULT_IN_PROGRESS:
+            self._notifyEndGame()
+            return
 
         self.startLock()
         
@@ -678,9 +683,12 @@ class ChessGame:
         self.result = result
         self.rule = rule
         if self.isStarted():
-            self.__currentPlayer._setReadyToMove(False)
-            for player in self.__players:
-                player.onGameEnded(self)
+            self._notifyEndGame()
+
+    def _notifyEndGame(self):
+        self.__currentPlayer._setReadyToMove(False)
+        for player in self.__players:
+            player.onGameEnded(self)
 
     def getMoves(self):
         """
